@@ -1,14 +1,14 @@
-u32 *convertSEXP_mle(struct ht *ht,u32 n,SEXP in,u32 *nout){
+static u32 *convertSEXP_mle(struct ht *ht,u32 n,SEXP in,u32 *nout){
  struct feature *f=ingestSEXP_mle(n,in);
  return(produce_mle((u32*)(f->x),ht,n,n,NULL,nout));
 }
 
-u32 *convertSEXP_kt(u32 n,SEXP in,u32 *nout){
+static u32 *convertSEXP_kt(u32 n,SEXP in,u32 *nout){
  struct feature *f=ingestSEXP_kt(n,in);
  return(produce_kt(f->x,is_double(f),n,NULL,nout));
 }
 
-u32 *convertSEXP(struct ht *ht,u32 n,SEXP in,u32 *nout,enum estimator estimator){
+static u32 *convertSEXP(struct ht *ht,u32 n,SEXP in,u32 *nout,enum estimator estimator){
  if(estimator==mle) return(convertSEXP_mle(ht,n,in,nout));
  if(estimator==kt) return(convertSEXP_kt(n,in,nout));
  return(NULL); //Unreachable due to estimator sanitisation upstream
