@@ -7,10 +7,10 @@ data(chain)
 vistla(Y~.,data=chain,threads=2)->V
 
 expected_paths<-list(
- M3=c("M3","M4","Y"),
- M2=c("M2","M3","M4","Y"),
- M1=c("M1","M2","M3","M4","Y"),
- X=c("X","M1","M2","M3","M4","Y")
+ M2=c("M2","M1","Y"),
+ M3=c("M3","M2","M1","Y"),
+ M4=c("M4","M3","M2","M1","Y"),
+ T=c("T","M4","M3","M2","M1","Y")
 )
 
 stopifnot(identical(
@@ -20,6 +20,6 @@ stopifnot(identical(
 
 stopifnot(identical(
  hierarchy(V)$name,
- rev(names(chain))
+ names(chain)
 ))
 
